@@ -65,8 +65,8 @@ MCTtest <- function(dose, resp, data = NULL, models, S = NULL,
     attr(critV, "Calc") <- FALSE
   }
   if(pVal){
-    pVals <- pValues(contMat, corMat, alpha, df,
-                     tStat, alternative, mvtcontrol)
+    pVals <- MCTpval(contMat, corMat, df, tStat,
+                     alternative, mvtcontrol)
   }
   res <- list(contMat = contMat, corMat = corMat, tStat = tStat,
               alpha = alpha, alternative = alternative[1])
@@ -157,6 +157,11 @@ checkAnalyArgs <- function(dose, resp, data, S, type,
   } else { # data handed over via vectors
     if(addCovars != ~1)
       stop("need to hand over data and covariates in data frame")
+    if(!(is.numeric(resp) && is.null(dim(resp)))) {
+      warning(cal[3], " is not a numeric but a ", class(resp)[1],
+              ", converting with as.numeric()")
+      resp <- as.numeric(resp)
+    }
     if(length(dose) != length(resp))
       stop(cal[2], " and ", cal[3], " not of equal length")
     dd <- na.action(data.frame(dose, resp))
@@ -183,7 +188,7 @@ checkAnalyArgs <- function(dose, resp, data, S, type,
       stop("S needs to be of class matrix")
     nD <- length(dd[[doseNam]])
     if(nrow(S) != nD | ncol(S) != nD)
-      stop("S and dose have non-confirming size")
+      stop("S and dose have non-conforming size")
   }
   ord <- order(dd[[doseNam]])
   dd <- dd[ord, ]
@@ -194,8 +199,8 @@ checkAnalyArgs <- function(dose, resp, data, S, type,
               doseNam=doseNam, respNam=respNam))
 }
 
-pValues <- function(contMat, corMat, alpha = 0.025, df,
-                    tStat, alternative = c("one.sided", "two.sided"),
+MCTpval <- function(contMat, corMat, df, tStat,
+                    alternative = c("one.sided", "two.sided"),
                     control = mvtnorm.control()){
   ## function to calculate p-values
   nD <- nrow(contMat)
@@ -222,8 +227,16 @@ pValues <- function(contMat, corMat, alpha = 0.025, df,
                   two.sided = matrix(rep(tStat, each = nMod), nrow = nMod))
   pVals <- numeric(nMod)
   for(i in 1:nMod){
-    pVals[i] <-   1 - pmvt(lower[,i], upper[,i], df = df,
-                           corr = corMat, algorithm = ctrl)
+    tmp <- 1 - pmvt(lower[,i], upper[,i], df = df,
+                    corr = corMat, algorithm = ctrl)
+    pVals[i] <- tmp
+    if(attr(tmp,"msg") != "Normal Completion"){
+      warning(sprintf("Warning from mvtnorm::pmvt: %s.", attr(tmp, "msg")))
+      if(attr(tmp, "msg") == "Covariance matrix not positive semidefinite"){
+        warning("Setting calculated p-value to NA")
+        pVals[i] <- NA
+      }
+    }
   }
   pVals
 }
